import java.util.*;
import java.util.StringTokenizer;

/**
 * @author Heiner K&uuml;cker
 */
public class Util
{

    /**
     * tokenweises Zerlegen des bergebenen
     * Strings.
     * 
     * @param pStr zeilenweise zu zerlegender String
     * @return String-Array mit den einzelnen Zeilen
     */
    public static String[] split(//--
    final String pStr, //--
    final String pDelimStr)
    {
        final StringTokenizer strTok = new StringTokenizer(pStr, pDelimStr);
        final ArrayList list = new ArrayList();
        while (strTok.hasMoreTokens())
        {
            list.add(strTok.nextToken());
        }
        return (String[]) list.toArray(new String[list.size()]);
    }

    /**
     * Teilstring von String links abschneiden, wenn mglich
     * 
     * @param srcStr Original-String
     * @param cutStr abzuschneidender String
     * @return abgeschnittener String
     */
    public static String cutLeft(//--
    final String srcStr, //--
    final String cutStr)
    {
        if (srcStr == null || cutStr == null)
        {
            return srcStr;
        }

        String retStr = srcStr;

        if (retStr.startsWith(cutStr))
        {
            retStr = retStr.substring(cutStr.length()); // cutStr abschneiden
        }

        return retStr;
    } //end method cutLeft

    /**
     * Teilstring von String rechts abschneiden, wenn mglich
     *
     * @param srcStr Original-String
     * @param cutStr abzuschneidender String
     * @return abgeschnittener String
     */
    public static String cutRight(//--
    final String srcStr, //--
    final String cutStr)
    {
        if (srcStr == null || cutStr == null)
        {
            return srcStr;
        }

        String retStr = srcStr;

        if (retStr.endsWith(cutStr))
        {
            // cutStr abschneiden
            retStr = retStr.substring(0, retStr.length() - cutStr.length());
        }

        return retStr;
    } // end method cutRight

    /**
     * Zurckgeben eines Strings aus dem
     * zusammengesetzten Elementen der bergebenen
     * Collection, getrennt mit dem bergebenen
     * Trenn-String.
     * 
     * @param pObjArr
     * @param pDelimStr
     * @return
     */
    public static String fillGapsWithDelim(//--
    final Collection pColl, //--
    final String pDelimStr)
    {
        if (pColl == null)
        {
            return null; // garbage in, garbage out
        }
        return fillGapsWithDelim(pColl.toArray(), pDelimStr);
    }
    /**
     * Zurckgeben eines Strings aus dem
     * zusammengesetzten Elementen des bergebenen
     * Arrays, getrennt mit dem bergebenen
     * Trenn-String.
     * 
     * @param pObjArr
     * @param pDelimStr
     * @return
     */
    public static String fillGapsWithDelim(//--
    final Object[] pObjArr, //--
    final String pDelimStr)
    {
        if (pObjArr == null)
        {
            return null; // garbage in, garbage out
        }

        final StringBuffer strBuff = new StringBuffer();
        for (int i = 0; i < pObjArr.length; i++)
        {
            strBuff.append(pObjArr[i]);
            if (i < pObjArr.length - 1)
            {
                strBuff.append(pDelimStr);
            }
        }
        return strBuff.toString();
    }

    /**
     * Zurckgeben eines Strings aus dem
     * zusammengesetzten Elementen des bergebenen
     * Arrays, getrennt mit dem bergebenen
     * Trenn-String.
     * Jedes Teilstck bekommt den spezifizierten
     * Prefix.
     * 
     * @param pObjArr
     * @param pDelimStr
     * @return
     */
    public static String arr2Str(//--
    final Object[] pObjArr, //--
    final String pDelimStr, //--
    final String pTokenPrefixStr)
    {
        if (pObjArr == null)
        {
            return null; // garbage in, garbage out
        }

        final StringBuffer strBuff = new StringBuffer();
        for (int i = 0; i < pObjArr.length; i++)
        {
            strBuff.append(pTokenPrefixStr);
            strBuff.append(pObjArr[i]);
            if (i < pObjArr.length - 1)
            {
                strBuff.append(pDelimStr);
            }
        }
        return strBuff.toString();
    }

    /**
     * Prfen auf 'null' oder Leerstring.
     * 
     * @param pStr zu prfender String
     * @return ob leer
     */
    public static boolean isEmpty(final String pStr)
    {
        return pStr == null || pStr.trim().length() <= 0;
    }

}
